pub struct DamageEventS2c {
pub entity_id: VarInt,
pub source_type_id: VarInt,
pub source_cause_id: VarInt,
pub source_direct_id: VarInt,
pub source_pos: Option<DVec3>,
}Fields
entity_id: VarIntThe ID of the entity taking damage
source_type_id: VarIntThe ID of the type of damage taken
source_cause_id: VarIntThe ID + 1 of the entity responsible for the damage, if present. If not present, the value is 0
source_direct_id: VarIntThe ID + 1 of the entity that directly dealt the damage, if present. If not present, the value is 0. If this field is present:
- and damage was dealt indirectly, such as by the use of a projectile, this field will contain the ID of such projectile;
- and damage was dealt directly, such as by manually attacking, this field will contain the same value as Source Cause ID.
source_pos: Option<DVec3>The Notchian server sends the Source Position when the damage was dealt by the /damage command and a position was specified